@@ -12,27 +12,12 @@
 ###################################################################################################
 spotReportMAMP <- function(spotConfig) {	
 	spotWriteLines(spotConfig$io.verbosity,2,"  Entering spotReportSAMP");	
-	rawB <- spotGetRawDataMatrixB(spotConfig);
-	spotPrint(spotConfig$io.verbosity,1,summary(rawB));
-	mergedData <- spotPrepareData(spotConfig)	
-	mergedB <- spotGetMergedDataMatrixB(mergedData, spotConfig);	
-	spotConfig=spotWriteBest(mergedData, spotConfig);
-	C1=spotConfig$alg.currentBest[nrow(spotConfig$alg.currentBest),]
-	#cat(sprintf("\n Best solution found with %d evaluations:\n",nrow(rawB)));
-	spotWriteLines(spotConfig$io.verbosity,1," ");
-	spotPrint(spotConfig$io.verbosity,1,paste("Best solution found with ",nrow(rawB)," evaluations:",sep=""));
-	spotPrint(spotConfig$io.verbosity,1,C1[1,]);
 	
 	######
 	spotInstAndLoadPackages(c("lme4","ggplot2","lattice"))
 	############################################################################	
 	pNames <- row.names(spotConfig$alg.roi); # names of fixed factors
-	yNames <- spotConfig$alg.resultColumn # names of observations
 	rawB <- spotConfig$alg.currentResult
-
-	###
-	#browser()
-	paramString <- paste(pNames,collapse=",") 
 	if(any(rawB$Y < 0))	
 		yLog= log(rawB$Y-min(rawB$Y)+1)
 	else
@@ -43,58 +28,39 @@ spotReportMAMP <- function(spotConfig) {
 	mamp.df$fSeed <- factor(mamp.df$fSeed)
 	for(i in 1:length(pNames))
 		mamp.df[[pNames[i]]] <- factor(mamp.df[[pNames[i]]])
-	#par(mfrow=c(2,1))
-	#qqnorm(mamp.df$y,main="(a)")
-	#qqline(mamp.df$y)
-	#qqnorm(mamp.df$yLog,main="(b) log. transformed")
-	#qqline(mamp.df$yLog)
 	str(mamp.df)
 	  
-	#pdf(file="glgxy2.pdf")
-	  
-	### erster plot
-	#library(lattice)
 	dev.new()
-	print(xyplot(as.formula(paste("y ~", pNames[1]," | fSeed",sep="")), data=mamp.df, 				#Frage: welchen Sinn machen die linien bei ungeordneten faktoren?
+	print(lattice::xyplot(as.formula(paste("y ~", pNames[1]," | fSeed",sep="")), data=mamp.df, 				#Frage: welchen Sinn machen die linien bei ungeordneten faktoren?
 	             main="",ylab="y",xlab=pNames[1],
 	             panel=function(x, y){
 	               m <- sort.list(x)
-	               panel.grid(h=-1,v=-1,lty=2)
-	               panel.xyplot(x[m], y[m])
-	               panel.loess(x[m], y[m], span=2, lty=1)
-	               panel.lmline(x[m], y[m], lty=2)
+	               lattice::panel.grid(h=-1,v=-1,lty=2)
+	               lattice::panel.xyplot(x[m], y[m])
+	               lattice::panel.loess(x[m], y[m], span=2, lty=1)
+	               lattice::panel.lmline(x[m], y[m], lty=2)
 	             }))		
 	dev.new()
-	print(xyplot(as.formula(paste("yLog ~", pNames[1]," | fSeed",sep="")), data=mamp.df, 				#Frage: welchen Sinn machen die linien bei ungeordneten faktoren?
+	print(lattice::xyplot(as.formula(paste("yLog ~", pNames[1]," | fSeed",sep="")), data=mamp.df, 				#Frage: welchen Sinn machen die linien bei ungeordneten faktoren?
 	             main="",ylab="yLog",xlab=pNames[1],
 	             panel=function(x, y){
 	               m <- sort.list(x)
-	               panel.grid(h=-1,v=-1,lty=2)
-	               panel.xyplot(x[m], y[m])
-	               panel.loess(x[m], y[m], span=2, lty=1)
-	               panel.lmline(x[m], y[m], lty=2)
+	               lattice::panel.grid(h=-1,v=-1,lty=2)
+	               lattice::panel.xyplot(x[m], y[m])
+	               lattice::panel.loess(x[m], y[m], span=2, lty=1)
+	               lattice::panel.lmline(x[m], y[m], lty=2)
 	             }))	
-	# print(xyplot(as.formula(paste("yLog ~ ", pNames[1]," | fSeed * algSeed",sep="")), data=mamp.df, 				#Frage: welchen Sinn machen die linien bei ungeordneten faktoren?
-	             # main="",ylab="y",xlab=pNames[1],
-	             # panel=function(x, y){
-	               # m <- sort.list(x)
-	               # panel.grid(h=-1,v=-1,lty=2)
-	               # panel.xyplot(x[m], y[m])
-	               # panel.loess(x[m], y[m], span=2, lty=1)
-	               # panel.lmline(x[m], y[m], lty=2)
-	             # }))
-	# dev.off()
 
  	h <- nlevels(mamp.df[[pNames[1]]])												#Frage: wie wird das mit mehreren Faktoren?
  	q <- nlevels(mamp.df$fSeed)
  	r <- nlevels(mamp.df$algSeed)
 	
 	###
-	op <- options(contrasts=c("contr.sum","contr.poly"))
+	options(contrasts=c("contr.sum","contr.poly"))
 	frml.log <- as.formula(paste("yLog ~", pNames[1]," + (1|fSeed) + (1|fSeed:",pNames[1],")",sep=""))
 	frml <- as.formula(paste("y ~", pNames[1]," + (1|fSeed) + (1|fSeed:",pNames[1],")",sep=""))
-	mamp.lmer.log <- lmer(frml.log, data=mamp.df)
-	mamp.lmer <- lmer(frml, data=mamp.df)
+	mamp.lmer.log <- lme4::lmer(frml.log, data=mamp.df)
+	mamp.lmer <- lme4::lmer(frml, data=mamp.df)
 	
 	###############################################################################
 	### NEW: Check Model Adequacy:
@@ -124,7 +90,7 @@ spotReportMAMP <- function(spotConfig) {
 	spotPrint(spotConfig$io.verbosity,1,mamp.lmer.log)
 	
 	###
-	VC<-VarCorr(mamp.lmer)
+	VC<-lme4::VarCorr(mamp.lmer)
 	sigma.gamma<-as.numeric(attr(VC[[paste("fSeed:",pNames[1],sep="")]],"stddev"))
 	sigma<-as.numeric(attr(VC,"sc"))
 	MSAB <- sigma^2 + r * sigma.gamma^2 
@@ -135,7 +101,7 @@ spotReportMAMP <- function(spotConfig) {
 	Y.j.$lower <- Y.j.$x - 0.5 * T * s
 	Y.j.$upper <- Y.j.$x + 0.5 * T * s	
 	###
-	VC.log<-VarCorr(mamp.lmer.log)
+	VC.log<-lme4::VarCorr(mamp.lmer.log)
 	sigma.gamma.log<-as.numeric(attr(VC.log[[paste("fSeed:",pNames[1],sep="")]],"stddev"))
 	sigma.log<-as.numeric(attr(VC.log,"sc"))
 	MSAB <- sigma.log^2 + r * sigma.gamma.log^2 
@@ -145,17 +111,7 @@ spotReportMAMP <- function(spotConfig) {
 	T <- qtukey(1-0.05,h,(h-1)*(q-1))/sqrt(2)
 	Y.j.log$lower <- Y.j.log$x - 0.5 * T * s
 	Y.j.log$upper <- Y.j.log$x + 0.5 * T * s
-	#if(any(rawB$Y < 0)){	
-	#	Y.j.log$lower= exp(Y.j.log$lower)+(min(rawB$Y)-1)
-	#	Y.j.log$upper= exp(Y.j.log$upper)+(min(rawB$Y)-1)
-	#	Y.j.log$x= exp(Y.j.log$x)+(min(rawB$Y)-1)
-	#}else{	
-	#	Y.j.log$lower= exp(Y.j.log$lower)
-	#	Y.j.log$upper= exp(Y.j.log$upper)
-	#	Y.j.log$x= exp(Y.j.log$x)
-	#}
-	#Y.j.
-	###
+
 	r <- length(unique(mamp.df$algSeed))
 	intervals <- function(formula,IN,...) {
 		prepanel.ci <- function(x, y, lx, ux, subscripts, ...){
@@ -169,19 +125,17 @@ spotReportMAMP <- function(spotConfig) {
 			y <- as.numeric(y)
 			lx <- as.numeric(lx[subscripts])
 			ux <- as.numeric(ux[subscripts])
-			panel.abline(h = unique(y), col = "grey")
-			panel.arrows(lx, y, ux, y, col = 'black',
+			lattice::panel.abline(h = unique(y), col = "grey")
+			lattice::panel.arrows(lx, y, ux, y, col = 'black',
 						 length = ar.len, ##unit = "native",
 						 angle = 90, code = 3)
-			panel.xyplot(x, y, pch = pch, ...)
+			lattice::panel.xyplot(x, y, pch = pch, ...)
 		}
-		dotplot(formula,data=IN,
+		lattice::dotplot(formula,data=IN,
 			  lx = IN[["lower"]], ux = IN[["upper"]],
 			  prepanel = prepanel.ci,
 			  panel = panel.ci, ...)
 	}  
-	# pdf(file="glg2intLog.pdf")  
-	### abschließender plot:
 	dev.new()
 	print(intervals(alg~x, Y.j.,xlab="y",ylab=pNames[1]))
 	dev.new()
